# Experiments

Torch-Uncertainty proposes various benchmarks to evaluate uncertainty quantification methods.

## Classification

### Images

* CIFAR-10
* CIFAR-100
* MNIST
* Tiny-ImageNet200

### Time-series

* UCR/UEA
  * Adiac
  * Beef
  * CricketX
  * CricketY
  * CricketZ
  * InlineSkate
  * Lightning7
  * Mallat
  * OliveOil
  * TwoPatterns

## Segmentation

### Road Traffic

* Cityscapes
* CamVid
* MUAD

## Regression

* UCI Regression
  * Boston Housing
  * Concrete
  * Energy Efficiency
  * Kin8nm
  * Naval Propulsion
  * Power Plant
  * Protein
  * Wine Quality

## Pixel Regression

*Work in progress*
